'use client';

import React from 'react';

import type { PlateContentProps } from '@udecode/plate-common/react';
import type { VariantProps } from 'class-variance-authority';

import { cn } from '@udecode/cn';
import {
  PlateContent,
  useEditorContainerRef,
  useEditorRef,
} from '@udecode/plate-common/react';
import { cva } from 'class-variance-authority';

const editorContainerVariants = cva(
  'relative w-[40rem] h-[20rem] bg-white cursor-text border border-slate-300  rounded-md  select-text caret-primary overflow-y-auto  selection:bg-brand/25 focus-visible:outline-none [&_.slate-selection-area]:border [&_.slate-selection-area]:border-brand/25 [&_.slate-selection-area]:bg-brand/15',
  {
    defaultVariants: {
      variant: 'default',
    },
    variants: {
      variant: {
        default: '',
        demo: 'h-[650px]',
        select: cn(
          'group rounded-md border border-zinc-200 ring-offset-white focus-within:ring-2 focus-within:ring-zinc-950 focus-within:ring-offset-2 dark:border-zinc-800 dark:ring-offset-zinc-950 dark:focus-within:ring-zinc-300',
          'has-[[data-readonly]]:w-fit has-[[data-readonly]]:cursor-default has-[[data-readonly]]:border-transparent has-[[data-readonly]]:focus-within:[box-shadow:none]'
        ),
      },
    },
  }
);

export const EditorContainer = ({
  className,
  variant,
  ...props
}: React.HTMLAttributes<HTMLDivElement> &
  VariantProps<typeof editorContainerVariants>) => {
  const editor = useEditorRef();
  const containerRef = useEditorContainerRef();

  return (
    <div
      id={editor.uid}
      ref={containerRef}
      className={cn(
        'ignore-click-outside/toolbar',
        editorContainerVariants({ variant }),
        className
      )}
      {...props}
    />
  );
};

EditorContainer.displayName = 'EditorContainer';

const editorVariants = cva(
  cn(
    'group/editor ',
    'relative w-full h-full px-16 pt-4  cursor-text select-text  whitespace-pre-wrap break-words',
    'rounded-md ring-offset-white  focus-visible:outline-none dark:ring-offset-zinc-950',
    'placeholder:text-zinc-500/80 [&_[data-slate-placeholder]]:top-[auto_!important] [&_[data-slate-placeholder]]:text-zinc-500/80 [&_[data-slate-placeholder]]:!opacity-100 dark:placeholder:text-zinc-400/80 dark:[&_[data-slate-placeholder]]:text-zinc-400/80',
    '[&_strong]:font-bold'
  ),
  {
    defaultVariants: {
      variant: 'default',
    },
    variants: {
      disabled: {
        true: 'cursor-not-allowed opacity-50',
      },
      focused: {
        true: 'ring-2 ring-zinc-950 ring-offset-2 dark:ring-zinc-300',
      },
      variant: {
        ai: 'w-full px-0 text-base md:text-sm',
        aiChat:
          'max-h-[min(70vh,320px)] w-full max-w-[700px] overflow-y-auto px-3 py-2 text-base md:text-sm',
        default:
          '',
        demo: 'size-full px-16 pb-72 pt-4 text-base sm:px-[max(64px,calc(50%-350px))]',
        fullWidth: 'size-full px-16 pb-72 pt-4 text-base sm:px-24',
        none: '',
        select: 'px-3 py-2 text-base data-[readonly]:w-fit',
      },
    },
  }
);

export type EditorProps = PlateContentProps &
  VariantProps<typeof editorVariants>;

export const Editor = React.forwardRef<HTMLDivElement, EditorProps>(
  ({ className, disabled, focused, variant, ...props }, ref) => {
    return (
        <PlateContent
          ref={ref}
          className={cn(
            editorVariants({
              disabled,
              focused,
              variant,
            }),
            className
          )}
          disabled={disabled}
          disableDefaultStyles
          {...props}
        />
    );
  }
);

Editor.displayName = 'Editor';
