import React from 'react';

import type { TEquationElement } from '@udecode/plate-math';

import { cn } from '@udecode/cn';
import { type SlateElementProps, SlateElement } from '@udecode/plate-common';
import { getEquationHtml } from '@udecode/plate-math';
import { RadicalIcon } from 'lucide-react';

export function EquationElementStatic({
  children,
  className,
  ...props
}: SlateElementProps) {
  const element = props.element as TEquationElement;

  const html = getEquationHtml({
    element,
    options: {
      displayMode: true,
      errorColor: '#cc0000',
      fleqn: false,
      leqno: false,
      macros: { '\\f': '#1f(#2)' },
      output: 'htmlAndMathml',
      strict: 'warn',
      throwOnError: false,
      trust: false,
    },
  });

  return (
    <SlateElement className={cn('my-1', className)} {...props}>
      <div
        className={cn(
          'group flex select-none items-center justify-center rounded-sm hover:bg-zinc-900/10 data-[selected=true]:bg-zinc-900/10 dark:hover:bg-zinc-50/10 dark:data-[selected=true]:bg-zinc-50/10',
          element.texExpression.length === 0 ? 'bg-zinc-100 p-3 pr-9 dark:bg-zinc-800' : 'px-2 py-1'
        )}
      >
        {element.texExpression.length > 0 ? (
          <span
            dangerouslySetInnerHTML={{
              __html: html,
            }}
          />
        ) : (
          <div className='flex h-7 w-full items-center gap-2 whitespace-nowrap text-sm text-zinc-500 dark:text-zinc-400'>
            <RadicalIcon className='size-6 text-zinc-500/80 dark:text-zinc-400/80' />
            <div>Add a Tex equation</div>
          </div>
        )}
      </div>
      {children}
    </SlateElement>
  );
}
