'use client';

import React, { useRef, useState } from 'react';

import type { TEquationElement } from '@udecode/plate-math';

import { cn, withRef } from '@udecode/cn';
import { useElement } from '@udecode/plate-common/react';
import { useEquationElement } from '@udecode/plate-math/react';
import { RadicalIcon } from 'lucide-react';
import { useSelected } from 'slate-react';

import { EquationPopoverContent } from './equation-popover';
import { PlateElement } from './plate-element';
import { Popover, PopoverTrigger } from './popover';

export const EquationElement = withRef<typeof PlateElement>(
  ({ children, className, ...props }, ref) => {
    const element = useElement<TEquationElement>();

    const selected = useSelected();
    const [open, setOpen] = useState(selected);
    const katexRef = useRef<HTMLDivElement | null>(null);

    useEquationElement({
      element,
      katexRef: katexRef,
      options: {
        displayMode: true,
        errorColor: '#cc0000',
        fleqn: false,
        leqno: false,
        macros: { '\\f': '#1f(#2)' },
        output: 'htmlAndMathml',
        strict: 'warn',
        throwOnError: false,
        trust: false,
      },
    });

    return (
      <PlateElement ref={ref} className={cn('my-1', className)} {...props}>
        <Popover open={open} onOpenChange={setOpen} modal={false}>
          <PopoverTrigger asChild>
            <div
              className={cn(
                'group flex cursor-pointer select-none items-center justify-center rounded-sm hover:bg-zinc-900/10 data-[selected=true]:bg-zinc-900/10 dark:hover:bg-zinc-50/10 dark:data-[selected=true]:bg-zinc-50/10',
                element.texExpression.length === 0
                  ? 'bg-zinc-100 p-3 pr-9 dark:bg-zinc-800'
                  : 'px-2 py-1'
              )}
              data-selected={selected}
              contentEditable={false}
              role='button'
            >
              {element.texExpression.length > 0 ? (
                <span ref={katexRef} />
              ) : (
                <div className='flex h-7 w-full items-center gap-2 whitespace-nowrap text-sm text-zinc-500 dark:text-zinc-400'>
                  <RadicalIcon className='size-6 text-zinc-500/80 dark:text-zinc-400/80' />
                  <div>Add a Tex equation</div>
                </div>
              )}
            </div>
          </PopoverTrigger>

          <EquationPopoverContent
            open={open}
            placeholder={`f(x) = \\begin{cases}\n  x^2, &\\quad x > 0 \\\\\n  0, &\\quad x = 0 \\\\\n  -x^2, &\\quad x < 0\n\\end{cases}`}
            isInline={false}
            setOpen={setOpen}
          />
        </Popover>

        {children}
      </PlateElement>
    );
  }
);
